| Title: | A matrix data storage object held in temporary files |
|---|---|
| Description: | A tabular style data object where most data is stored outside main memory. A buffer is used to speed up access to data. |
| Authors: | Ben Bolstad <[email protected]> |
| Maintainer: | Ben Bolstad <[email protected]> |
| License: | LGPL (>= 2) |
| Version: | 1.77.0 |
| Built: | 2026-05-29 08:28:24 UTC |
| Source: | https://github.com/bioc/BufferedMatrix |
'as.BufferedMatrix' will coerce the supplied object into a BufferedMatrix. 'is.BufferedMatrix' checks whether the supplied argument is a BufferedMatrix.
as.BufferedMatrix(x, bufferrows=1, buffercols=1,directory=getwd()) is.BufferedMatrix(x)as.BufferedMatrix(x, bufferrows=1, buffercols=1,directory=getwd()) is.BufferedMatrix(x)
x |
an R object |
bufferrows |
number of rows to be buffered if the row buffer is activated |
buffercols |
number of columns to be buffered |
directory |
path to directory where temporary files should be stored |
These functions are useful for converting between R
matrix objects and
BufferedMatrix objects.
B. M. Bolstad <[email protected]>
This is a class representation of a buffered matrix (of numeric data). In this case data is primarily stored outide main memory in temporary files.
Objects can be created using the function createBufferedMatrix
rawBufferedMatrix:a pointer to an external structure used to access and store the matrix data.
rownames:rownames for the matrix.
colnames:colnames for the matrix.
signature(object = "BufferedMatrix"): Returns the number of columns in the matrix
signature(object = "BufferedMatrix"): Returns the number of rows in the matrix
signature(object = "BufferedMatrix"): Returns the
dimensions of the matrix
signature(object = "BufferedMatrix"): Returns
the number of columns and the number of rows to be stored in the
buffer
signature(object = "BufferedMatrix"):
Set the buffer size or resize it
signature(object = "BufferedMatrix"): matrix accessor
signature(object = "BufferedMatrix"): matrix
replacer
signature(object = "BufferedMatrix"): prints basic
information about the BufferedMatrix out to screen
signature(object = "BufferedMatrix"):
returns TRUE if the row buffer is active and FALSE otherwise.
signature(object = "BufferedMatrix"):
returns TRUE if the row buffer is inactive and FALSE otherwise.
signature(object = "BufferedMatrix"):
Activate the row buffer.
signature(object = "BufferedMatrix"):
Deactivate the row buffer
signature(object = "BufferedMatrix"):
Make a copy of the BufferedMatrix
signature(object = "BufferedMatrix"):
return the initial part of the string used for temporary files
signature(object = "BufferedMatrix"):
return the location where temporary files are stored
signature(object = "BufferedMatrix"):
return the fully pathed filenames for each column in the matrix
signature(object = "BufferedMatrix"):
apply a function elementwise
signature(object = "BufferedMatrix"): Compute the
exponential elementwise of the matrix
signature(object = "BufferedMatrix"): Compute the
square-root elementwise of the matrix
signature(object = "BufferedMatrix"): Compute
$x^power$ elementwise of the matrix
signature(object = "BufferedMatrix"): Compute
logarithm elementwise of the matrix
signature(object = "BufferedMatrix"): Returns a
vector containing maximums by column
signature(object = "BufferedMatrix"): Returns a
vector containing maximums by row
signature(object = "BufferedMatrix"): Returns a
vector containing means by column
signature(object = "BufferedMatrix"): Returns a
vector containing means by row
signature(object = "BufferedMatrix"): Returns a
vector containing minimums by column
signature(object = "BufferedMatrix"): Returns a
vector containing minimums by row
signature(object = "BufferedMatrix"): Returns a
vector containing sample variances by column
signature(object = "BufferedMatrix"): Returns a
vector containing sample variances by row
signature(object = "BufferedMatrix"): Returns a
vector containing sample standard deviations by column
signature(object = "BufferedMatrix"): Returns a
vector containing sample standard deviations by row
signature(object = "BufferedMatrix"): Returns a
vector containing sum by column
signature(object = "BufferedMatrix"): Returns a
vector containing sum by row
signature(object = "BufferedMatrix"): Returns a
vector containing medians by column
signature(object = "BufferedMatrix"): Returns a
vector containing medians by row. Best only used when the matrix is
in RowMode (otherwise it is extremely slow)
signature(object = "BufferedMatrix"): Returns the
maximum of all elements in the matrix
signature(object = "BufferedMatrix"): Returns the
minimum of all elements in the matrix
signature(object = "BufferedMatrix"): Returns the
sample variance of all elements in the matrix
signature(object = "BufferedMatrix"): Returns the
sample standard deviations of all elements in the matrix
signature(object = "BufferedMatrix"): Returns the
sum of all elements in the matrix
signature(object = "BufferedMatrix"): Returns the
mean of all elements in the matrix
signature(object = "BufferedMatrix"):
apply a function columnwise. Returns either a vector or BufferedMatrix.
signature(object = "BufferedMatrix"):
apply a function row-wise. Returns either a vector or BufferedMatrix.
signature(object = "BufferedMatrix"):
coerce BufferedMatrix into a regular R matrix
signature(object = "BufferedMatrix"):
gets data from BufferedMatrix and returns it in another
BufferedMatrix
signature(object = "BufferedMatrix") : access
the row names
signature(object = "BufferedMatrix") : access
the column names
signature(object = "BufferedMatrix") : replace
the row names
signature(object = "BufferedMatrix") : replace
the column names
signature(object = "BufferedMatrix") : Access
the row and column names
signature(object = "BufferedMatrix") : Replace
the row and column names
signature(object = "BufferedMatrix") :
Toggles the Read Only mode on and off
signature(object = "BufferedMatrix") :
Finds out if it is in Read Only Mode
signature(object = "BufferedMatrix") :
Give amount of RAM currently in use by BufferedMatrix object
signature(object = "BufferedMatrix") :
Give amount of disk space currently in use by BufferedMatrix object
as(matrix,BufferedMatrix):Coerce matrix to BufferedMatrix.
as(BufferedMatrix,matrix):Coerce the Buffered to matrix.
AddColumn:Add an additional column to the matrix. Will be all empty (set to 0)
MoveStorageDirectory:Move the temporary files used to store the matrix from one location to another
B. M. Bolstad [email protected]
Creates a Buffered Matrix object
createBufferedMatrix(rows, cols=0, bufferrows=1, buffercols=1,prefix="BM",directory=getwd())createBufferedMatrix(rows, cols=0, bufferrows=1, buffercols=1,prefix="BM",directory=getwd())
rows |
Number of rows in the matrix |
cols |
Initial number of coulmns in the matrix |
bufferrows |
number of rows to be buffered if the row buffer is activated |
buffercols |
number of columns to be buffered |
prefix |
String to be used as start of name for any temporary files |
directory |
path to directory where temporary files should be stored |
B. M. Bolstad <[email protected]>